@@ -99,7 +99,7 @@ class PipedashWorker:
             "error": str(e)
         })
 
-    def send_worker_response(self, jobId, message):
+    def send_worker_response(self, jobId, message, retry=False):
 
         message = {
             "worker_id": self._worker_id,
@@ -111,12 +111,17 @@ class PipedashWorker:
         }
         message_str = json.dumps(message, default=serializeDTO)
 
-        self._lock.acquire()
         try:
-            self._mq_channel.basic_publish("", "pipedash_command_queue", message_str)
-        finally:
-            self._lock.release()
-
+            self._lock.acquire()
+            try:
+                self._mq_channel.basic_publish("", "pipedash_command_queue", message_str)
+            finally:
+                self._lock.release()
+        except pika.exceptions.ConnectionClosed:
+            log.error("We reconnect queue")
+            self.connect_to_queue()
+            if not retry:
+                self.send_worker_response(jobId, message, True)
 
     async def run_worker_queue(self):
         connection = await aio_pika.connect_robust(
@@ -136,7 +141,7 @@ class PipedashWorker:
                 registration_data = self._registeredComponents[identifier]
                 await self.send_registration_data(registration_data)
 
-            await self.send_heartbeat_message()
+            self.send_heartbeat_message()
 
             # Declaring queue
             queue = await self.channel.declare_queue(
@@ -277,8 +282,8 @@ class PipedashWorker:
                 raise Exception("Please check your properties again. Something is wrong.")
         return instance
 
-    async def send_heartbeat_message(self):
-       # threading.Timer(5.0, self.send_heartbeat_message).start()
+    def send_heartbeat_message(self):
+        threading.Timer(5.0, self.send_heartbeat_message).start()
         list_of_identifier = []
         for key in self._registeredComponents.keys():
             list_of_identifier.append(key)
@@ -292,13 +297,17 @@ class PipedashWorker:
         }
         message_str = json.dumps(message, default=serializeDTO)
 
-        if self._mq_channel is not None:
-            #await self._heartbeat_channel.default_exchange.publish(aio_pika.Message(body=message_str.encode()), "pipedash_heartbeat_queue")
-            self._mq_channel.basic_publish("", "pipedash_heartbeat_queue", message_str)
-        else:
-            log.error("Your message channel is not connected! Can not send heartbeat!")
+        try:
+            if self._mq_channel is not None:
+                #await self._heartbeat_channel.default_exchange.publish(aio_pika.Message(body=message_str.encode()), "pipedash_heartbeat_queue")
+                self._mq_channel.basic_publish("", "pipedash_heartbeat_queue", message_str)
+            else:
+                log.error("Your message channel is not connected! Can not send heartbeat!")
+        except pika.exceptions.ConnectionClosed:
+            log.error("We reconnect queue")
+            self.connect_to_queue()
 
-    async def send_registration_data(self, registration_data):
+    async def send_registration_data(self, registration_data, retry=False):
 
         message = {
             "worker_id": self._worker_id,
@@ -309,13 +318,17 @@ class PipedashWorker:
         }
         message_str = json.dumps(message, default=serializeDTO)
 
-        if self._mq_channel is not None:
-            #await self._heartbeat_channel.default_exchange.publish(aio_pika.Message(body=message_str.encode()), "pipedash_command_queue")
-            self._mq_channel.basic_publish("", "pipedash_command_queue", message_str)
-        else:
-            log.error("Your message channel is not connected! Can not send any command!")
-
-        pass
+        try:
+            if self._mq_channel is not None:
+                #await self._heartbeat_channel.default_exchange.publish(aio_pika.Message(body=message_str.encode()), "pipedash_command_queue")
+                self._mq_channel.basic_publish("", "pipedash_command_queue", message_str)
+            else:
+                log.error("Your message channel is not connected! Can not send any command!")
+        except pika.exceptions.ConnectionClosed:
+            log.error("We reconnect queue")
+            self.connect_to_queue()
+            if not retry:
+                self.send_registration_data(registration_data, True)
 
     def registerDrawable(self, component: Type[TDrawableComponent], name: str, description: str, identifier: str, imageurl: str):
         if identifier is None:
